The Hidex 300 SL
================

The **Hidex 300 SL** is a an automatic liquid scintillation counter
with an automatic sample changer and a triple photomultiplier tube detection assembly.
It is used to measure the activity of liquid scintillation samples.

Key features of the Hidex 300 SL:

- **Automatic sample changer**:
  Typical scintillation vials are loaded in sample racks.
  A robotic loading arm transfer the vials from the sample racks to the measurement chamber.
- **Triple-PMT detector technology**:
  It utilizes three PMTs aligned at 120° from each other with a highly reflective measurement chamber design.
  This provide optimal measurement geometry and maximises light collection.
  Its lead shield design provides good shielding, minimizes instrument weight, and reduces background effects.
- **TDCR technology**:
  Absolute activity counting using triple-to-double coincidence ratio (TDCR) method.
  It also supports using an external standard method.
- **Temperature stabilization**:
  It supports measurement at a controlled temperature optimal for the scintillation cocktails used.

Find more details about this instrument in the
`Hidex website <https://www.hidex.com/products/liquid-scintillation-counters/hidex-300-sl>`_.
